#
# spec file for package perl-version
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name version
Name:           perl-version
Version:        0.9929
Release:        bp155.2.10
Summary:        Perl extension for Version Objects
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/L/LE/LEONT/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
Version objects were added to Perl in 5.10. This module implements version
objects for older version of Perl and provides the version object API for
all versions of Perl. All previous releases before 0.74 are deprecated and
should not be used due to incompatible API changes. Version 0.77 introduces
the new 'parse' and 'declare' methods to standardize usage. You are
strongly urged to set 0.77 as a minimum in your code, e.g.

  use version 0.77; # even for Perl v.5.10.0

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc CHANGES README

%changelog
* Sat Apr 17 2021 Tina Müller <timueller+perl@suse.de>
- updated to 0.9929
  see /usr/share/doc/packages/perl-version/CHANGES
  0.9929
  * Upgrade to ppport 3.62
  * Import fix for core build warning
  0.9928
  * silence warning for our LC_NUMERIC_LOCK macro
* Wed Sep 23 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.9928
  see /usr/share/doc/packages/perl-version/CHANGES
* Fri Aug 21 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.9927
  see /usr/share/doc/packages/perl-version/CHANGES
* Sat Apr 21 2018 coolo@suse.com
- updated to 0.9924
  see /usr/share/doc/packages/perl-version/CHANGES
* Thu Apr 12 2018 coolo@suse.com
- updated to 0.9921
  see /usr/share/doc/packages/perl-version/CHANGES
  0.9921 - 2018-04-11
  * Silence overly compulsive GCC 7 warning
  https://rt.cpan.org/Ticket/Display.html?id=123477
  * Improve docs regarding trailing zeros
  https://rt.cpan.org/Ticket/Display.html?id=122858
* Mon Apr  9 2018 coolo@suse.com
- updated to 0.9920
  see /usr/share/doc/packages/perl-version/CHANGES
  0.9920 - 2018-04-08
  * Backwards compatible locale handling
  https://rt.cpan.org/Ticket/Display.html?id=125042
  0.9919 - 2018-04-08
  * Core improvements to locale handling
  https://rt.cpan.org/Ticket/Display.html?id=124563
* Sat Apr 22 2017 coolo@suse.com
- updated to 0.9918
  see /usr/share/doc/packages/perl-version/CHANGES
* Mon May 30 2016 coolo@suse.com
- updated to 0.9917
  see /usr/share/doc/packages/perl-version/Changes
  2016-05-29  John Peacock  <john.peacock@havurah-software.org>
  * flow: Merged <hotfix> '0.9917' to <develop> ('develop').
  [5d83ccf33657] [tip] <develop>
  * .hgtags:
  Added tag 0.9917 for changeset 464516d1bf10
  [2e2892f29539]
  * flow: Merged <hotfix> '0.9917' to <master> ('default').
  [464516d1bf10] [0.9917]
  * flow: Closed <hotfix> '0.9917'.
  [b1bfcb0828d1] <hotfix/0.9917>
  * Makefile.PL, README, lib/version.pm, lib/version/regex.pm, t/00impl-
  pp.t, t/01base.t, t/02derived.t, t/03require.t, t/05sigdie.t,
  t/06noop.t, t/07locale.t, t/08_corelist.t, t/09_list_util.t,
  vperl/vpp.pm, vutil/lib/version/vxs.pm:
  Prep for release
  [5cadbb0ba7dd] <hotfix/0.9917>
  * t/04strict_lax.t:
  A couple more tests to make sure the captures work
  [c0650c7fee2a] <hotfix/0.9917>
  2016-05-25  John Peacock  <john.peacock@havurah-software.org>
  * lib/version/regex.pm:
  Ordering counts when you have greedy matching
  [7dd7f57f958c] <hotfix/0.9917>
  * t/04strict_lax.t:
  Add a test before fixing bug
  [6a59439b71e6] <hotfix/0.9917>
  2016-04-01  John Peacock  <john.peacock@havurah-software.org>
  * flow: Created branch 'hotfix/0.9917'.
  [d287474c7e4b] <hotfix/0.9917>
* Mon Mar 21 2016 coolo@suse.com
- updated to 0.9916
  see /usr/share/doc/packages/perl-version/Changes
  2016-03-18  John Peacock  <john.peacock@havurah-software.org>
  * .hgtags:
  Added tag 0.9916 for changeset 15763a2f6075
  [3cffe3d1d62a] [tip]
  * flow: Merged <release> '0.9916' to <master> ('default').
  [15763a2f6075] [0.9916]
  * flow: Merged <release> '0.9916' to <develop> ('develop').
  [8f1e8495674d] <develop>
  * flow: Closed <release> '0.9916'.
  [6bb061a73cc5] <release/0.9916>
  * Makefile.PL, README, lib/version.pm, lib/version/regex.pm, t/00impl-
  pp.t, t/01base.t, t/02derived.t, t/03require.t, t/05sigdie.t,
  t/06noop.t, t/07locale.t, t/08_corelist.t, t/09_list_util.t,
  vperl/vpp.pm, vutil/lib/version/vxs.pm:
  Prep for release to CPAN
  [0969e36be548] <release/0.9916>
  * t/07locale.t:
  Another fix from core Perl
  [8eb36834cb1c] <release/0.9916>
  * vutil/vutil.c:
  Remove unused variables
  [26abf30c5c59] <release/0.9916>
  * vutil/vutil.c:
  Macros must be on separate lines.
  [39a531dfece5] <release/0.9916>
  * flow: Created branch 'release/0.9916'.
  [3f095fd910eb] <release/0.9916>
* Tue Mar  8 2016 coolo@suse.com
- updated to 0.9915
  see /usr/share/doc/packages/perl-version/Changes
  2016-03-05  John Peacock  <john.peacock@havurah-software.org>
  * .hgtags:
  Added tag 0.9915 for changeset dc1d08d9ee5c
  [5b2cf3e1882d] [tip]
  * flow: Merged <release> '0.9915' to <master> ('default').
  [dc1d08d9ee5c] [0.9915]
  * flow: Merged <release> '0.9915' to <develop> ('develop').
  [a68f41046a12] <develop>
  * flow: Closed <release> '0.9915'.
  [898452696d61] <release/0.9915>
  * Makefile.PL, README, lib/version.pm, lib/version/regex.pm, t/00impl-
  pp.t, t/01base.t, t/02derived.t, t/03require.t, t/05sigdie.t,
  t/06noop.t, t/07locale.t, t/08_corelist.t, t/09_list_util.t,
  vperl/vpp.pm, vutil/lib/version/vxs.pm:
  Prep for documentation-only release to CPAN
  [7b7226db9d45] <release/0.9915>
  * flow: Created branch 'release/0.9915'.
  [476b405c963e] <release/0.9915>
  2016-02-24  John Peacock  <john.peacock@havurah-software.org>
  * .hgtags:
  Added tag 0.9914 for changeset 16a529f3aab3
  [6571f70630c1]
  * flow: Merged <release> '0.9914' to <master> ('default').
  [16a529f3aab3] [0.9914]
  * flow: Merged <release> '0.9914' to <develop> ('develop').
  [c870c13f6545] <develop>
  * flow: Closed <release> '0.9914'.
  [4d90e8da2284] <release/0.9914>
  2016-02-18  John Peacock  <john.peacock@havurah-software.org>
  * Makefile.PL, README, lib/version.pm, lib/version/regex.pm, t/00impl-
  pp.t, t/01base.t, t/02derived.t, t/03require.t, t/05sigdie.t,
  t/06noop.t, t/07locale.t, t/08_corelist.t, t/09_list_util.t,
  vperl/vpp.pm, vutil/lib/version/vxs.pm:
  Prep for release to CPAN
  [76756591216f] <release/0.9914>
  * flow: Created branch 'release/0.9914'.
  [6c9706b0b31c] <release/0.9914>
  2016-02-17  John Peacock  <john.peacock@havurah-software.org>
  * flow: Merged <hotfix> '0.9913_01' to <develop> ('develop').
  [87fd2c8420dd] <develop>
  * .hgtags:
  Added tag 0.9913_01 for changeset 81095ad53ee3
  [8a7c575cc4c2]
  * flow: Merged <hotfix> '0.9913_01' to <master> ('default').
  [81095ad53ee3] [0.9913_01]
  * flow: Closed <hotfix> '0.9913_01'.
  [6c5f5883412e] <hotfix/0.9913_01>
  * Makefile.PL, README, lib/version.pm, lib/version/regex.pm, t/00impl-
  pp.t, t/01base.t, t/02derived.t, t/03require.t, t/05sigdie.t,
  t/06noop.t, t/07locale.t, t/08_corelist.t, t/09_list_util.t,
  t/10_lyon.t, t/coretests.pm, vperl/vpp.pm, vutil/lib/version/vxs.pm,
  vutil/vutil.c:
  Apply missed changeset from leont and prep for release
  [fc08284a87cf] <hotfix/0.9913_01>
  * flow: Created branch 'hotfix/0.9913_01'.
  [24bd39aa58c2] <hotfix/0.9913_01>
* Fri Feb 19 2016 coolo@suse.com
- updated to 0.9913
  see /usr/share/doc/packages/perl-version/Changes
  2016-02-16  John Peacock  <john.peacock@havurah-software.org>
  * .hgtags:
  Added tag 0.9913 for changeset f5eda39012f8
  [acfb12d302c3] [tip]
  * flow: Merged <release> '0.9913' to <master> ('default').
  [f5eda39012f8] [0.9913]
  * flow: Merged <release> '0.9913' to <develop> ('develop').
  [8dcd1df93adb] <develop>
  * flow: Closed <release> '0.9913'.
  [b27dba2c01a1] <release/0.9913>
  * .hgignore, MANIFEST.SKIP:
  Ignore ctags file
  [c0f9aca57284] <release/0.9913>
  2016-02-01  John Peacock  <john.peacock@havurah-software.org>
  * vutil/vutil.c:
  Perl uses more strict C flags
  [12902d257437] <release/0.9913>
  * Makefile.PL, README, lib/version.pm, lib/version/regex.pm, t/00impl-
  pp.t, t/01base.t, t/02derived.t, t/03require.t, t/05sigdie.t,
  t/06noop.t, t/07locale.t, t/08_corelist.t, t/09_list_util.t,
  vperl/vpp.pm, vutil/lib/version/vxs.pm:
  Bump version for release
  [8f24755b6f11] <release/0.9913>
  * flow: Created branch 'release/0.9913'.
  [f189d92b9db1] <release/0.9913>
  2016-01-21  John Peacock  <john.peacock@havurah-software.org>
  * flow: Merged <hotfix> '0.9912_03' to <develop> ('develop').
  [4159ccbf8bb3] <develop>
  * .hgtags:
  Added tag 0.9912_03 for changeset c0117603b8ff
  [0d12dbfef4e2]
  * flow: Merged <hotfix> '0.9912_03' to <master> ('default').
  [c0117603b8ff] [0.9912_03]
  * flow: Closed <hotfix> '0.9912_03'.
  [8df7847932f0] <hotfix/0.9912_03>
  * Makefile.PL, README, lib/version.pm, lib/version/regex.pm, t/00impl-
  pp.t, t/01base.t, t/02derived.t, t/03require.t, t/05sigdie.t,
  t/06noop.t, t/07locale.t, t/08_corelist.t, t/09_list_util.t,
  vperl/vpp.pm, vutil/lib/version/vxs.pm:
  Prep for release
  [02821023f2e7] <hotfix/0.9912_03>
  * vutil/Makefile.PL, vutil/vutil.c, vutil/vutil.h, vutil/vxs.inc,
  vutil/vxs.xs:
  Apply pull request from bulk88: vutil.c and vxs.inc/vxs.xs must be
  combined to be the same .o file for static to work. Previously there
  was a vutil.o and a vxs.o which were combined by the linker.
  Combining the 2 .o files and making all symbols static removes
  plt/got indirection on ELF OSes. On Win32 vxs.dll exports nothing
  except boot_version__vxs, the linux version shouldn't export
  anything either.
  [187bfa1881be] <hotfix/0.9912_03>
  * t/00impl-pp.t, t/01base.t, t/02derived.t, t/03require.t:
  Use portable options so Windows does not fail
  [03b91e2c0ef5] <hotfix/0.9912_03>
  2016-01-07  John Peacock  <john.peacock@havurah-software.org>
  * flow: Created branch 'hotfix/0.9912_03'.
  [9cd0e1255aac] <hotfix/0.9912_03>
  * flow: Merged <hotfix> '0.9912_02' to <develop> ('develop').
  [bd6f13c85dac] <develop>
  * .hgtags:
  Added tag 0.9912_02 for changeset 7a3f1ac2d502
  [523da51cfeeb]
  * flow: Merged <hotfix> '0.9912_02' to <master> ('default').
  [7a3f1ac2d502] [0.9912_02]
  * flow: Closed <hotfix> '0.9912_02'.
  [02758f2cf016] <hotfix/0.9912_02>
  2016-01-03  John Peacock  <john.peacock@havurah-software.org>
  * Makefile.PL, README, lib/version.pm, lib/version/regex.pm, t/00impl-
  pp.t, t/01base.t, t/02derived.t, t/03require.t, t/05sigdie.t,
  t/06noop.t, t/07locale.t, t/08_corelist.t, t/09_list_util.t,
  vperl/vpp.pm, vutil/lib/version/vxs.pm:
  Bump version for release
  [620f6585a091] <hotfix/0.9912_02>
  * t/07locale.t:
  Wrong skip offset and more generous locale possibilities for comma
  locale
  [3ef6df5d370a] <hotfix/0.9912_02>
  * flow: Created branch 'hotfix/0.9912_02'.
  [840b1c8ec916] <hotfix/0.9912_02>
  2016-01-02  John Peacock  <john.peacock@havurah-software.org>
  * .hgtags:
  Added tag 0.9912_01 for changeset 18591196a1ff
  [2458e15f2559]
  * flow: Merged <release> '0.9912_01' to <master> ('default').
  [18591196a1ff] [0.9912_01]
  * flow: Merged <release> '0.9912_01' to <develop> ('develop').
  [cfb4d643f07d] <develop>
  * flow: Closed <release> '0.9912_01'.
  [35fe333646f7] <release/0.9912_01>
  * t/10_lyon.t:
  Magic v-string introduced in 5.8.1
  [d9fc86689acc] <release/0.9912_01>
  2015-12-31  John Peacock  <john.peacock@havurah-software.org>
  * Makefile.PL, README, lib/version.pm, lib/version/regex.pm, t/00impl-
  pp.t, t/01base.t, t/02derived.t, t/03require.t, t/05sigdie.t,
  t/06noop.t, t/07locale.t, t/08_corelist.t, t/09_list_util.t,
  t/10_lyon.t, t/coretests.pm, vperl/vpp.pm, vutil/lib/version/vxs.pm:
  Bump version for alpha CPAN release
  [6ea02663b047] <release/0.9912_01>
  2016-01-01  John Peacock  <john.peacock@havurah-software.org>
  * flow: Created branch 'release/0.9912_01'.
  [f6c197863de6] <release/0.9912_01>
  * t/07locale.t, vutil/vutil.c:
  Resolve https://rt.cpan.org/Ticket/Display.html?id=102272
  [353b8d985519] <develop>
  * t/coretests.pm, vperl/vpp.pm, vutil/vutil.c:
  Resolve https://rt.cpan.org/Ticket/Display.html?id=98744
  [498a66726d64] <develop>
  * t/coretests.pm:
  Lyon Compromise resolves
  https://rt.cpan.org/Ticket/Display.html?id=93340
  [5a035f18e9ff] <develop>
  * lib/version/Internals.pod:
  Resolve https://rt.cpan.org/Ticket/Display.html?id=107114
  [9d032859e53a] <develop>
  * lib/version.pod:
  Resolve https://rt.cpan.org/Ticket/Display.html?id=107113
  [ae087294fa7d] <develop>
  * Makefile.PL:
  Resolve https://rt.cpan.org/Ticket/Display.html?id=106782
  [b0b4ec7a38c4] <develop>
  * vperl/vpp.pm:
  Resolve https://rt.cpan.org/Ticket/Display.html?id=105315
  [4326618b03a6] <develop>
  * vperl/vpp.pm:
  Resolve https://rt.cpan.org/Ticket/Display.html?id=101841
  [52e06b6a200a] <develop>
  * vutil/vutil.c:
  Resolve https://rt.cpan.org/Ticket/Display.html?id=101647
  [268ca104b457] <develop>
  * flow: Merged <feature> 'lyon_compromise' to <develop> ('develop').
  [0e41e5282422] <develop>
  * flow: Closed <feature> 'lyon_compromise'.
  [59ceec2dde96] <feature/lyon_compromise>
  * .hgignore, t/coretests.pm, vutil/vutil.c:
  Restore skip leading zeros for qv
  [c55cfae045cd] <feature/lyon_compromise>
  2015-12-31  John Peacock  <john.peacock@havurah-software.org>
  * t/10_lyon.t:
  Fix up TODO test
  [98c6a366f9a0] <feature/lyon_compromise>
  * lib/version.pm, vperl/vpp.pm:
  Clean up pure-Perl implementation
  [d43308467dad] <feature/lyon_compromise>
  2015-07-17  Leon Timmermans  <fawaka@gmail.com>
  * MANIFEST, lib/version.pm, t/10_lyon.t, t/coretests.pm, vperl/vpp.pm,
  vutil/vutil.c:
  Apply lyon-compromise patch from Leon Timmermans
  [a644337cfb8d] <feature/lyon_compromise>
  2015-12-31  John Peacock  <john.peacock@havurah-software.org>
  * .hgignore, t/coretests.pm, vperl/vpp.pm, vutil/vutil.c:
  Revert leading zeros change
  [e03d04d5bd44] <feature/lyon_compromise>
  * flow: Created branch 'feature/lyon_compromise'.
  [7cd41e636d45] <feature/lyon_compromise>
  2015-10-18  John Peacock  <john.peacock@havurah-software.org>
  * .hgtags:
  Added tag 0.9912 for changeset 00927ca7d355
  [ed92b0de01fe]
  * .hgtags:
  Manual merge from develop
  [00927ca7d355] [0.9912]
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.9912
  see /usr/share/doc/packages/perl-version/Changes
  2015-01-20  John Peacock  <john.peacock@havurah-software.org>
  * .hgtags, Makefile.PL, README, lib/version.pm, lib/version/regex.pm,
  t/00impl-pp.t, t/01base.t, t/02derived.t, t/03require.t,
  t/05sigdie.t, t/06noop.t, t/07locale.t, t/08_corelist.t,
  t/09_list_util.t, t/coretests.pm, vperl/vpp.pm,
  vutil/lib/version/vxs.pm, vutil/vutil.c:
  flow: Merged <hotfix> '0.9912' to <develop> ('develop').
  [646e8c5c4769] [tip] <develop>
  * .hgtags:
  Added tag 0.9912 for changeset d95ec600e4b8
  [d0a8bd97c2d8]
  * flow: Merged <hotfix> '0.9912' to <master> ('default').
  [d95ec600e4b8] [0.9912]
  * flow: Closed <hotfix> '0.9912'.
  [d4a3dc59d496] <hotfix/0.9912>
  * Makefile.PL, README, lib/version.pm, lib/version/regex.pm, t/00impl-
  pp.t, t/01base.t, t/02derived.t, t/03require.t, t/05sigdie.t,
  t/06noop.t, t/07locale.t, t/08_corelist.t, t/09_list_util.t,
  vperl/vpp.pm, vutil/lib/version/vxs.pm:
  Ready for release
  [2e8e456b5f69] <hotfix/0.9912>
  * vperl/vpp.pm, vutil/vutil.c:
  Ignore leading zeros when parsing qv versions
  [8d4f602d49bc] <hotfix/0.9912>
  * t/coretests.pm:
  Add test before fixing behavior.
  [73ad9715162c] <hotfix/0.9912>
  * .shipit, t/coretests.pm, vperl/vpp.pm, vutil/vutil.c:
  Finish reverting the ill-advised alpha->normal code
  [468d3b498d58] <hotfix/0.9912>
  * flow: Created branch 'hotfix/0.9912'.
  [a9f6f567d387] <hotfix/0.9912>
  * vperl/vpp.pm, vutil/vutil.c:
  Ignore leading zeros when parsing qv versions
  [7e36d3c46d88] [default/development] <release/0.9912>
  * t/coretests.pm:
  Add test before fixing behavior.
  [d4befa972a57] <release/0.9912>
  * vperl/vpp.pm, vutil/vutil.c:
  Initial cap on warnings to be consistent with perldig
  [d0cce4fa33ac] <release/0.9912>
  2015-01-19  John Peacock  <john.peacock@havurah-software.org>
  * vperl/vpp.pm, vutil/vutil.c:
  Always use numeric warnings and prefix them to make perldiag more
  useful
  [6345b0e62b3e] [github/development] <release/0.9912>
  2015-01-18  John Peacock  <john.peacock@havurah-software.org>
  * flow: Created branch 'release/0.9912'.
  [0a04b5e70190] <release/0.9912>
  * Initial:
  Merge in dupe heads
  [397c2045b0c1] [default/master, github/master]
  2015-01-18  John Peacock  <jpeacock@cpan.org>
  * Initial:
  Commit an empty file to start over
  [8becec36c4af]
  2015-01-18  John Peacock  <john.peacock@havurah-software.org>
  * flow: Merged <feature> 'alpha_normal' to <develop> ('develop').
  [7f1bbc22403f] <develop>
  * flow: Closed <feature> 'alpha_normal'.
  [d4ec344eaf25] <feature/alpha_normal>
  * Makefile.PL, README, lib/version.pm, lib/version/regex.pm, t/00impl-
  pp.t, t/01base.t, t/02derived.t, t/03require.t, t/05sigdie.t,
  t/06noop.t, t/07locale.t, t/08_corelist.t, t/09_list_util.t,
  vperl/vpp.pm, vutil/lib/version/vxs.pm:
  Bump versions to 0.9912
  [cdba24734cbb] <feature/alpha_normal>
  * README:
  Hopefully this will be true
  [9bb4a810f212] <feature/alpha_normal>
  * Makefile.PL:
  Picky, picky, picky. Resolves
  https://rt.cpan.org/Public/Bug/Display.html?id=101600
  [05740f0e1d4a] <feature/alpha_normal>
  * .shipit, Makefile.PL, lib/version.pm, lib/version/regex.pm, t
  /00impl-pp.t, t/01base.t, t/02derived.t, t/03require.t,
  t/05sigdie.t, t/06noop.t, t/07locale.t, t/08_corelist.t,
  t/09_list_util.t, t/coretests.pm, vperl/vpp.pm,
  vutil/lib/version/vxs.pm, vutil/vutil.c:
  Reapply this change now
  [0652edbe911d] <feature/alpha_normal>
  * flow: Created branch 'feature/alpha_normal'.
  [8cb2f4e319c3] <feature/alpha_normal>
  2015-01-17  John Peacock  <john.peacock@havurah-software.org>
  * .hgtags:
  Removed tag v0.9910
  [eb66489945fd] <develop>
  * .hgtags:
  Added tag 0.9910 for changeset 4d00adc23f19
  [6d03680705f6] <develop>
  * flow: Merged <hotfix> '0.9911' to <develop> ('develop').
  [55a3bfc0b3fc] <develop>
  * .hgtags:
  Added tag 0.9911 for changeset fb394f4ac5fc
  [3127ec2a07b6]
  * flow: Merged <hotfix> '0.9911' to <master> ('default').
  [fb394f4ac5fc] [0.9911]
  * flow: Closed <hotfix> '0.9911'.
  [d4bec652869d] <hotfix/0.9911>
  * .shipit:
  Need to disable this because it doesn't understand hotfix branches
  [2b1b81b21756] <hotfix/0.9911>
  * Makefile.PL, lib/version.pm, lib/version/regex.pm, t/00impl-pp.t,
  t/01base.t, t/02derived.t, t/03require.t, t/05sigdie.t, t/06noop.t,
  t/07locale.t, t/08_corelist.t, t/09_list_util.t, t/coretests.pm,
  vperl/vpp.pm, vutil/lib/version/vxs.pm, vutil/vutil.c:
  Pull out the changed behavior of normal(), since it breaks M::B
  [a6c92bf7e426] <hotfix/0.9911>
  * .shipit:
  Restore the Finish step and remember to use it this time.
  [9a8e87ab3743] <hotfix/0.9911>
  * flow: Created branch 'hotfix/0.9911'.
  [83a460962b55] <hotfix/0.9911>
  * .shipit:
  Checking in changes prior to tagging of version 0.9910.
  Changelog diff is:
  [1f732d03f5eb]
  * .hgtags:
  Added tag v0.9910 for changeset 4d00adc23f19
  [58b1b7d17dd4]
  * flow: Merged <release> '0.9910' to <master> ('default').
  [4d00adc23f19] [0.9910]
  * flow: Merged <release> '0.9910' to <develop> ('develop').
  [8ac3661f1f71] <develop>
  * flow: Closed <release> '0.9910'.
  [6890ac6a6a3e] <release/0.9910>
  2014-06-22  John Peacock  <john.peacock@havurah-software.org>
  * README, vutil/vutil.c, vutil/vxs.inc:
  [PATCH] version distribution dVAR updates. commit
  9bdbb2bdbd72d8d02cb8bcb0d27e7eeeacd415af Author: Jarkko Hietaniemi
  <jhi@iki.fi>
  [267cb6097a5f] <release/0.9910>
  2014-12-23  David Mitchell  <davem@iabyn.com>
  * README, vutil/vutil.c:
  [PATCH] 'version': vutil.c: silence overflow warnings
  From a3f461a88988cef9a89c13ab42c50556750ede51 Mon Sep 17 00:00:00
  2001 Running 'clang -fsanitize=undefined' on the perl test suite
  triggers a number of warnings:
  vutil.c:354:9: runtime error: signed integer overflow: 750283776 +
  1705032704 cannot be represented in type 'int' vutil.c:354:25:
  runtime error: signed integer overflow: 6 * 1000000000 cannot be
  represented in type 'int' vutil.c:355:10: runtime error: signed
  integer overflow: 1000000000 * 10 cannot be represented in type
  'int'
  This is because the version string parsing code takes a "maybe
  overflow, then check to see if we've overflown" approach. Which is
  perfectly fine, but clashes with clang.
  This commit makes it take the opposite approach of checking each
  time
  * before* doing the += mult*i and mult*=10 steps.
  A bit clunky, but ASan only allows you to disable these warnings on
  a per-function basis, and it's a reasonably large function.
  I suspect that the block of code above this may need similar
  treatment, but as it wasn't triggering clang warnings, I didn't look
  at it.
  - -- vutil.c | 17 ++++++++++++----- 1 file changed, 12 insertions(+),
  5 deletions(-)
  [d90a6cd2ecba] <release/0.9910>
  2014-08-30  John Peacock  <john.peacock@havurah-software.org>
  * .shipit:
  Ready to release now
  [bfd261163ee7] <release/0.9910>
  * .shipit:
  Try new Finish step
  [67dc070b3131] <release/0.9910>
  2014-08-23  John Peacock  <john.peacock@havurah-software.org>
  * .hgignore, Makefile.PL:
  Force the VERSION so we can control the tarball name
  [616ea2110028] <release/0.9910>
  * vutil/vutil.c, vutil/vutil.h:
  Apply suggested changes from Karl Williamson
  [61cfdfe0c2e5] <release/0.9910>
  * flow: Created branch 'release/0.9910'.
  [a91839728adf] <release/0.9910>
* Wed Oct  1 2014 coolo@suse.com
- updated to 0.9909
  Compatibility release for Perl 5.20.1.  Apply two patches from bleadperl
  (one which shipped with 5.20.0 and one from bleadperl) so that a clean
  release can be applied prior to 5.20.1 being shipped.  Holding back a few
  other improvements, so expect 0.9910 shortly.
* Tue Jun 17 2014 coolo@suse.com
- updated to 0.9908, see Changes
* Thu Oct 25 2012 opensuse@dstoecker.de
- update to 0.9901
* Sat Jul 14 2012 chris@computersalat.de
- initial package 0.87
  * created by cpanspec 1.78.03
* Sat Jul 14 2012 chris@computersalat.de
- update to 0.87
  * see Changes file for more info
    http://cpansearch.perl.org/src/JPEACOCK/version-0.87/Changes
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Oct 18 2010 chris@computersalat.de
- update to 0.83
  o please see Changes file
* Mon Sep  6 2010 chris@computersalat.de
- recreated by cpanspec 1.78
- build only for SLE_10
* Mon Aug 23 2010 pascal.bleser@opensuse.org
- complete rewrite of the dreadful auto-generated spec file
- upgrade to 0.82
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Thu Jun 18 2009 chris@computersalat.de
- spec fix for perl-macros
* Wed Jun 17 2009 chris@computersalat.de
- update to 0.76
- added perl-macros
  o autogen filelist with perl_gen_filelist
- new package for obs
